==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/PlanWsparciaDiagnozaPodstawaKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.generic.GenericDPSObject;

@GeneratePojoBuilder
public class PlanWsparciaDiagnozaPodstawaKey extends GenericDPSObject {
    /**
     * PLAN_WSPARCIA_DIAGNOZA_PODSTAWA.PLAN_WSPARCIA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long planWsparciaId;

    /**
     * PLAN_WSPARCIA_DIAGNOZA_PODSTAWA.DIAGNOZA_REALIZACJA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long diagnozaRealizacjaId;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return PLAN_WSPARCIA_DIAGNOZA_PODSTAWA.PLAN_WSPARCIA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getPlanWsparciaId() {
        return planWsparciaId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-10 10:45:42
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * PLAN_WSPARCIA_DIAGNOZA_PODSTAWA.PLAN_WSPARCIA_ID
     *
     * @param planWsparciaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setPlanWsparciaId(Long planWsparciaId) {
        this.planWsparciaId = planWsparciaId;
    }

    /**
     * @return PLAN_WSPARCIA_DIAGNOZA_PODSTAWA.DIAGNOZA_REALIZACJA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getDiagnozaRealizacjaId() {
        return diagnozaRealizacjaId;
    }

    /**
     * PLAN_WSPARCIA_DIAGNOZA_PODSTAWA.DIAGNOZA_REALIZACJA_ID
     *
     * @param diagnozaRealizacjaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDiagnozaRealizacjaId(Long diagnozaRealizacjaId) {
        this.diagnozaRealizacjaId = diagnozaRealizacjaId;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        PlanWsparciaDiagnozaPodstawaKey other = (PlanWsparciaDiagnozaPodstawaKey) that;
        return (this.getPlanWsparciaId() == null ? other.getPlanWsparciaId() == null : this.getPlanWsparciaId().equals(other.getPlanWsparciaId()))
            && (this.getDiagnozaRealizacjaId() == null ? other.getDiagnozaRealizacjaId() == null : this.getDiagnozaRealizacjaId().equals(other.getDiagnozaRealizacjaId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getPlanWsparciaId() == null) ? 0 : getPlanWsparciaId().hashCode());
        result = prime * result + ((getDiagnozaRealizacjaId() == null) ? 0 : getDiagnozaRealizacjaId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", planWsparciaId=").append(planWsparciaId);
        sb.append(", diagnozaRealizacjaId=").append(diagnozaRealizacjaId);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/PlanWsparciaDiagnozaPodstawaKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

@GeneratePojoBuilder
public class PlanWsparciaDiagnozaPodstawaKey extends GenericDPSObject {
    /**
     * PLAN_WSPARCIA_DIAGNOZA_PODSTAWA.PLAN_WSPARCIA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long planWsparciaId;

    /**
     * PLAN_WSPARCIA_DIAGNOZA_PODSTAWA.DIAGNOZA_REALIZACJA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long diagnozaRealizacjaId;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return PLAN_WSPARCIA_DIAGNOZA_PODSTAWA.PLAN_WSPARCIA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getPlanWsparciaId() {
        return planWsparciaId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-13 16:02:47
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * PLAN_WSPARCIA_DIAGNOZA_PODSTAWA.PLAN_WSPARCIA_ID
     *
     * @param planWsparciaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setPlanWsparciaId(Long planWsparciaId) {
        this.planWsparciaId = planWsparciaId;
    }

    /**
     * @return PLAN_WSPARCIA_DIAGNOZA_PODSTAWA.DIAGNOZA_REALIZACJA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getDiagnozaRealizacjaId() {
        return diagnozaRealizacjaId;
    }

    /**
     * PLAN_WSPARCIA_DIAGNOZA_PODSTAWA.DIAGNOZA_REALIZACJA_ID
     *
     * @param diagnozaRealizacjaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDiagnozaRealizacjaId(Long diagnozaRealizacjaId) {
        this.diagnozaRealizacjaId = diagnozaRealizacjaId;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        PlanWsparciaDiagnozaPodstawaKey other = (PlanWsparciaDiagnozaPodstawaKey) that;
        return (this.getPlanWsparciaId() == null ? other.getPlanWsparciaId() == null : this.getPlanWsparciaId().equals(other.getPlanWsparciaId()))
            && (this.getDiagnozaRealizacjaId() == null ? other.getDiagnozaRealizacjaId() == null : this.getDiagnozaRealizacjaId().equals(other.getDiagnozaRealizacjaId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getPlanWsparciaId() == null) ? 0 : getPlanWsparciaId().hashCode());
        result = prime * result + ((getDiagnozaRealizacjaId() == null) ? 0 : getDiagnozaRealizacjaId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", planWsparciaId=").append(planWsparciaId);
        sb.append(", diagnozaRealizacjaId=").append(diagnozaRealizacjaId);
        sb.append("]");
        return sb.toString();
    }
}
